@@ -1,7 +1,7 @@
 #---------------------------------------------------------------------
 package Dist::Zilla::Role::ModuleInfo;
 #
-# Copyright 2009 Christopher J. Madsen
+# Copyright 2010 Christopher J. Madsen
 #
 # Author: Christopher J. Madsen <perl@cjmweb.net>
 # Created: 25 Sep 2009
@@ -14,17 +14,17 @@ package Dist::Zilla::Role::ModuleInfo;
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See either the
 # GNU General Public License or the Artistic License for more details.
 #
-# ABSTRACT: Create Module::Build::ModuleInfo object from Dist::Zilla::File
+# ABSTRACT: Create Module::Metadata object from Dist::Zilla::File
 #---------------------------------------------------------------------
 
-our $VERSION = '0.08';
-# This file is part of Dist-Zilla-Plugins-CJM 3.03 (December 7, 2010)
+our $VERSION = '3.04';
+# This file is part of Dist-Zilla-Plugins-CJM 3.04 (December 20, 2010)
 
 use Moose::Role;
 
 use autodie ':io';
 use File::Temp ();
-use Module::Build::ModuleInfo ();
+use Module::Metadata ();
 use Path::Class qw(dir file);
 
 
@@ -32,23 +32,26 @@ sub get_module_info
 {
   my $self = shift;
   my $file = shift;
-  # Any additional parameters get passed to M::B::ModuleInfo->new_from_file
+  # Any additional parameters get passed to M::Metadata->new_from_file
 
-  # Module::Build::ModuleInfo doesn't have a new_from_string method,
+  # To be safe, reset the global variables controlling IO to their defaults:
+  local ($/, $,, $\) = "\n";
+
+  # Module::Metadata doesn't have a new_from_string method,
   # so we'll write the current contents to a temporary file:
 
   my $tempdirObject = File::Temp->newdir();
   my $dir     = dir("$tempdirObject");
   my $modPath = file($file->name);
 
-  # Module::Build::ModuleInfo only cares about the basename of the file:
+  # Module::Metadata only cares about the basename of the file:
   my $tempname = $dir->file($modPath->basename);
 
   open(my $temp, '>', $tempname);
   print $temp $file->content;
   close $temp;
 
-  return Module::Build::ModuleInfo->new_from_file("$tempname", @_)
+  return Module::Metadata->new_from_file("$tempname", @_)
       or die "Unable to get module info from " . $file->name . "\n";
 } # end get_module_info
 
@@ -59,18 +62,20 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Role::ModuleInfo - Create Module::Build::ModuleInfo object from Dist::Zilla::File
+Dist::Zilla::Role::ModuleInfo - Create Module::Metadata object from Dist::Zilla::File
 
 =head1 VERSION
 
-This document describes version 0.08 of
-Dist::Zilla::Role::ModuleInfo, released December 7, 2010
-as part of Dist-Zilla-Plugins-CJM version 3.03.
+This document describes version 3.04 of
+Dist::Zilla::Role::ModuleInfo, released December 20, 2010
+as part of Dist-Zilla-Plugins-CJM version 3.04.
 
 =head1 DESCRIPTION
 
 Plugins implementing ModuleInfo may call their own C<get_module_info>
-method to construct a L<Module::Build::ModuleInfo> object.
+method to construct a L<Module::Metadata> object.  (Module::Metadata
+is the new name for Module::Build::ModuleInfo, now that it's been
+split from the Module-Build distribution.)
 
 =head1 METHODS
 
@@ -78,14 +83,18 @@ method to construct a L<Module::Build::ModuleInfo> object.
 
   my $info = $plugin->get_module_info($file);
 
-This constructs a Module::Build::ModuleInfo object from the contents
+This constructs a Module::Metadata object from the contents
 of a C<$file> object that does Dist::Zilla::Role::File.  Any additional
-arguments are passed along to C<< Module::Build::ModuleInfo->new_from_file >>.
+arguments are passed along to C<< Module::Metadata->new_from_file >>.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
 Dist::Zilla::Role::ModuleInfo requires no configuration files or environment variables.
 
+=head1 DEPENDENCIES
+
+L<Module::Metadata>.
+
 =head1 INCOMPATIBILITIES
 
 None reported.
